==> glibc-2.22.tar.xz: glibc-2.22/sysdeps/m68k/m680x0/fpu/s_scalbn.c <==
/* Copyright (C) 1996-2015 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library.  If not, see
   <http://www.gnu.org/licenses/>.  */

#define scalbln __no_scalbln_decl
#define scalblnf __no_scalblnf_decl
#define scalblnl __no_scalblnl_decl
#define __scalbln __no__scalbln_decl
#define __scalblnf __no__scalblnf_decl
#define __scalblnl __no__scalblnl_decl
#include <math.h>
#undef scalbln
#undef scalblnf
#undef scalblnl
#undef __scalbln
#undef __scalblnf
#undef __scalblnl

#ifndef suffix
#define suffix /*empty*/
#endif
#ifndef float_type
#define float_type double
#endif

#define __CONCATX(a,b) __CONCAT(a,b)

float_type
__CONCATX(__scalbn,suffix) (x, exp)
     float_type x;
     int exp;
{
  return __m81_u(__CONCATX(__scalbn,suffix))(x, exp);
}
weak_alias (__CONCATX(__scalbn,suffix), __CONCATX(scalbn,suffix))
strong_alias (__CONCATX(__scalbn,suffix), __CONCATX(__scalbln,suffix))

#include <shlib-compat.h>
#if SHLIB_COMPAT (libc, GLIBC_2_1, GLIBC_2_20)
compat_symbol (libc, __CONCATX(__scalbn,suffix), __CONCATX(scalbln,suffix),
	       GLIBC_2_1);
#endif

==> glibc_2.26.orig.tar.xz: glibc-2.26/sysdeps/m68k/m680x0/fpu/s_scalbn.c <==
/* Copyright (C) 1996-2017 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library.  If not, see
   <http://www.gnu.org/licenses/>.  */

#define scalbln __no_scalbln_decl
#define scalblnf __no_scalblnf_decl
#define scalblnl __no_scalblnl_decl
#define __scalbln __no__scalbln_decl
#define __scalblnf __no__scalblnf_decl
#define __scalblnl __no__scalblnl_decl
#include <math.h>
#undef scalbln
#undef scalblnf
#undef scalblnl
#undef __scalbln
#undef __scalblnf
#undef __scalblnl

#ifndef suffix
#define suffix /*empty*/
#endif
#ifndef float_type
#define float_type double
#endif

#define __CONCATX(a,b) __CONCAT(a,b)

float_type
__CONCATX(__scalbn,suffix) (float_type x, int exp)
{
  return __m81_u(__CONCATX(__scalbn,suffix))(x, exp);
}
strong_alias (__CONCATX(__scalbn,suffix), __CONCATX(__scalbln,suffix))

#include <shlib-compat.h>
#if SHLIB_COMPAT (libc, GLIBC_2_1, GLIBC_2_20)
compat_symbol (libc, __CONCATX(__scalbn,suffix), __CONCATX(scalbln,suffix),
	       GLIBC_2_1);
#endif
